@@ -8,7 +8,7 @@ from itertools import product
 import numpy as np
 import shapely.geometry as sgeom
 from shapely.geometry import mapping
-from shapely.prepared import prep
+from shapely.vectorized import contains
 import fiona
 import geojson
 import orjson
@@ -66,7 +66,11 @@ class MapPolygon(sgeom.MultiPolygon):
 
         for one, other in couples:
             if one.contains(other) and one != other:
-                polygons.remove(other)
+                try:
+                    polygons.remove(other)
+                except ValueError:
+                    pass
+
         return MapPolygon(polygons)
 
     def union(self, other):
@@ -176,87 +180,22 @@ class MapPolygon(sgeom.MultiPolygon):
     def make_mask_array(self, lons: np.ndarray, lats: np.ndarray):
         """
         生成边界以外的遮罩（掩膜）数组
-
         Args:
             lons (np.ndarray): 经度矩阵（2维）
             lats (np.ndarray): 纬度矩阵（2维）
-
         Returns:
             np.ndarray: 遮罩（掩膜）数组
         """
-        x = np.atleast_1d(lons)
-        y = np.atleast_1d(lats)
+        lons = np.atleast_1d(lons)
+        lats = np.atleast_1d(lats)
 
-        if len(x.shape) != 2 or len(y.shape) != 2:
+        if len(lons.shape) != 2 or len(lats.shape) != 2:
             raise ValueError("x或y不是2维数组")
 
-        if x.shape != y.shape:
+        if lons.shape != lats.shape:
             raise ValueError("x和y的形状不匹配")
-        prepared = prep(self)
 
-        def recursion(x, y):
-            """递归判断数组x和y的点是否落入多边形中."""
-            xmin, xmax = x.min(), x.max()
-            ymin, ymax = y.min(), y.max()
-            xflag = np.isclose(xmin, xmax)
-            yflag = np.isclose(ymin, ymax)
-            mask = np.zeros(x.shape, dtype=bool)
-
-            # 散点重合为单点的情况.
-            if xflag and yflag:
-                point = sgeom.Point(xmin, ymin)
-                if prepared.contains(point):
-                    mask[:] = True
-                else:
-                    mask[:] = False
-                return mask
-
-            xmid = (xmin + xmax) / 2
-            ymid = (ymin + ymax) / 2
-
-            # 散点落在水平和垂直直线上的情况.
-            if xflag or yflag:
-                line = sgeom.LineString([(xmin, ymin), (xmax, ymax)])
-                if prepared.contains(line):
-                    mask[:] = True
-                elif prepared.intersects(line):
-                    if xflag:
-                        m1 = (y >= ymin) & (y <= ymid)
-                        m2 = (y >= ymid) & (y <= ymax)
-                    if yflag:
-                        m1 = (x >= xmin) & (x <= xmid)
-                        m2 = (x >= xmid) & (x <= xmax)
-                    if m1.any():
-                        mask[m1] = recursion(x[m1], y[m1])
-                    if m2.any():
-                        mask[m2] = recursion(x[m2], y[m2])
-                else:
-                    mask[:] = False
-                return mask
-
-            # 散点可以张成矩形的情况.
-            box = sgeom.box(xmin, ymin, xmax, ymax)
-            if prepared.contains(box):
-                mask[:] = True
-            elif prepared.intersects(box):
-                m1 = (x >= xmid) & (x <= xmax) & (y >= ymid) & (y <= ymax)
-                m2 = (x >= xmin) & (x <= xmid) & (y >= ymid) & (y <= ymax)
-                m3 = (x >= xmin) & (x <= xmid) & (y >= ymin) & (y <= ymid)
-                m4 = (x >= xmid) & (x <= xmax) & (y >= ymin) & (y <= ymid)
-                if m1.any():
-                    mask[m1] = recursion(x[m1], y[m1])
-                if m2.any():
-                    mask[m2] = recursion(x[m2], y[m2])
-                if m3.any():
-                    mask[m3] = recursion(x[m3], y[m3])
-                if m4.any():
-                    mask[m4] = recursion(x[m4], y[m4])
-            else:
-                mask[:] = False
-
-            return mask
-
-        return ~recursion(x, y)
+        return ~contains(self, lons, lats)
 
 
 def read_mapjson(fp, wgs84=True):
@@ -355,6 +294,7 @@ def get_adm_maps(
     record: str = "all",
     only_polygon: bool = False,
     wgs84=True,
+    simplify=False,
     *args,
     **kwargs,
 ):
@@ -392,6 +332,7 @@ def get_adm_maps(
                                 Defaults to False.
         wgs84 (bool, 可选): 是否使用 WGS84 坐标系, 若为 True 则转为 WGS84 坐标,
                                 若为 False 则使用高德默认的 GCJ02 火星坐标。Defaults to True.
+        simplify  (bool, 可选): 是否对边界进行简化, 若为 True 则进行简化处理, 否则不做简化。Defaults to True.
 
     异常:
         ValueError: 当传入的等级
@@ -501,6 +442,22 @@ def get_adm_maps(
     )
     gdf["geometry"] = map_polygons
 
+    if simplify:
+        area = gdf["geometry"].area.sum()
+        tolerance = area / 10000
+        simple_geometry = gdf.simplify(tolerance=tolerance)
+
+        geometries = []
+        for g in simple_geometry:
+            if isinstance(g, sgeom.Polygon):
+                geometries.append(MapPolygon([g]))
+            elif isinstance(g, sgeom.MultiPolygon):
+                geometries.append(MapPolygon(g))
+            else:
+                geometries.append(g)
+
+        gdf["geometry"] = geometries
+
     if len(gdf) == 0:
         raise MapNotFoundError("未找到指定地图的边界文件")
 
